#include <string.h>
#include <stdio.h>
#include <ctype.h>
#include "macro.h"

#define iskanji(c) ((c)>=0x81 && (c)<=0x9f || (c)>=0xe0 && (c)<=0xfc)
#define iskanji2(c) ((c)>=0x40 && (c)<=0x7e || (c)>=0x80 && (c)<=0xfc)

extern FILE *dbg;
//extern char *dir;
extern int  wnb, ct;
extern char cj[WordNumb][JSentLen], Dbg;

isVowel(char c)
{
    int  j = 0;
    if(c == 'a' || c == 'e' || c == 'i' || c == 'o' || c == 'u') j = 1;
    if(c == 'A' || c == 'E' || c == 'I' || c == 'O' || c == 'U') j = 1;
    return(j);
}

ptcpy(c, pt1, pt2)
char c[], *pt1, *pt2;
{
     char *pt;
     pt = pt1;
     while(pt != pt2) *(c++) = *(pt++);
    *c = '\0';
}

wdcpy(char *st1, char *st2)
{
    while(*st2 && (*st2 != ' ')) *st1++ = *st2++;
    *st1 = '\0';
}

// \̊댯
//cutoff2(a, x, i)
//char *a;
//int  x, i;
//{
//    int  ln;
//    char *b;
//    ln = strlen(a);
//    if(x < ln){
//      b = a+x+i;	*(a+x) = '\0';
//      if(ln > x+1) strcat(a, b);       // 
//    }
//}

cutoff(a, x, i)
char *a;
int  x,  i;
{
    int  ln;
    char b[2000];
    ln = strlen(a);
    if(x < ln){
      strcpy(b, a+x+i);
      *(a+x) = '\0';
      if(ln > x+1) strcat(a, b);
    }
}

ptcut(pt, i)
char *pt;
int  i;
{
    char *pta, *ptq;
    int  ln;
    ln = strlen(pt);
    if(i >= ln) *pt = '\0';
    else{
      pta = pt;	ptq = pt + i;
      do{
	*(pta++) = *(ptq++);
      } while(*ptq);
      *pta = '\0';
    }
}

ptptcut(pt1, pt2)
char *pt1, *pt2;
{
    char *pta = pt1, *ptz = pt2;
    do{
      *(pta++) = *(++ptz);
    }	while(*ptz);
}

insertc(a, i, c, ln)
char a[], c;
int  i, ln;
{
    int  j;
    if(i < ln)
      for(j = ln; j > i; j--) a[j] = a[j-1];
    a[i] = c;	a[ln+1] = '\0';
}

ptinsert(pt, s)
char *pt, s[];
{
    char dums[4000];
    strcpy(dums, pt);	strcpy(pt, s);	strcat(pt, dums);
}

left(a, c, i)
char a[], c[];
int  i;
{
    int  x;
    if(i > strlen(c)) i = strlen(c);
    for(x = 0; x <= i-1; x++) a[x] = c[x];
    a[i] = '\0';
}

replaces(a, k, ln2, c)
char a[], c[];
int  k, ln2;
{
    char *bpt, dumc[4000];
    bpt = a + k + ln2;
    strcpy(dumc, c);	strcat(dumc, bpt);
    *(a+k) = '\0';	strcat(a, dumc);
}

ptreplace(pt, ln, c)
char c[], *pt;
int  ln;
{
    char *pt2 = pt+ln, dums[4000];
    strcpy(dums, pt2);	*pt = '\0';
    strink(pt, c, dums, (char*)0);
}

strink(s1, s2)
char *s1, *s2;
{
    char *p = s1, *q, **a = &s2;
    while(*p) ++p;
    while(q = *(a++)) while(*q) *p++ = *q++;
    *p = '\0';
}

right(c, b, i)
unsigned char *c, *b;
int  i;
{
    int  d;
    unsigned char *pt;
    if(i >= 0){
      d = strlen(c)-i;
      if(d >= 0) pt = c+d;	else pt = c;
      strcpy(b, pt);
    }
    else *b = '\0';
}

mid(a, i, j, b)
int  i, j;
char a[], b[];
{
    char c[4000];
    left(c, a, i+j-1);	right(c, b, j);
}

instr(a, b)
char *a, *b;
{
    int  j = 1;
    char *pt;
    if(pt = (char *)strstr(a, b)){
      while( a != pt--) j++;
      return(j);
    }
    else return(0);
}

ninstr(n, a, b)
int  n;
char *a, *b;
{
    int  inst;
    char *pta;
    pta = a+n-1;
    if(inst = instr(pta, b)) return(n+inst-1);
    else return(0);
}

instrc(a, b)
char *a, b;
{
    int  j = 1;
    char *pt;
    if(pt = (char *)index(a, b)){
      while(a != pt--) j++;
      return(j);
    }
    else return(0);
}

ninstrc(n, a, b)
int  n;
char *a, b;
{
    int  inst;
    char *pta;
    pta = a + n - 1;
    if(inst = instrc(pta, b)) return(n+inst-1);
    else return(0);
}

swap(a, b)
char a[], b[];
{
    char c[2000];
    strcpy(c, a);	strcpy(a, b);	strcpy(b, c);
}

val(nstr)
char nstr[];
{
    int  ln, i, keta = 1, n = 0;
    ln = strlen(nstr);
    for(i = ln-1; i >= 0; i--){
      n += (keta * (nstr[i]-'0'));	keta *= 10;
    }
    return(n);
}

zentoint(zenkaku)
char zenkaku[];
{
    int  i, ln, numb = 0, keta = 1;
    ln = strlen(zenkaku)/2-1;
    for(i = ln; i >= 0; i--){
      numb += keta*(zenkaku[i*2+1]-79);	keta *= 10;
    }
    return(numb);
}

nhantozen(hankaku,zenkaku)
char hankaku[], zenkaku[];
{
    int  i, ln;
    ln = strlen(hankaku)-1;
    for(i = 0; i <= ln; i++){
      if(hankaku[i] == ','){
	zenkaku[2*i] = '\0';	strcat(zenkaku, "C");
      }
      else{
	zenkaku[2*i] = -126;
	if(hankaku[1] < 97) zenkaku[2*i+1] = hankaku[i]+31;
	else zenkaku[2*i+1] = hankaku[i]-225;
      }
    }
    zenkaku[2*i] = '\0';
}

numbtohan(numb, hankaku)
int  numb;
char hankaku[];
{
    int  i, dig, ln;
    char invdigits[9];
    for(i = 0; ; i++){
      dig = numb % 10;
      invdigits[i] = dig +'0';
      numb -= dig;
      if(numb == 0) break;
      else numb /= 10;
    }
    ln = i;
    invdigits[ln+1] = '\0';
    for(i = 0; i <= ln; i++) hankaku[i] = invdigits[ln-i];
    hankaku[ln+1] = '\0';
}

/*strstr(str1, str2)
unsigned char *str1, *str2;
{
    int  str;
    str = (char*)str1;
    STRST:
    if(strlen(str) < strlen(str2)) return('\0');
	str = index(str, *str2);
    if(str == '\0') return('\0');
    if(strncmp(str, str2, strlen(str2))==0) return(str);
    str++;	goto STRST;
}*/

/*------- predit ------------------------------------------*/

predit(wdh, no)
int  *no;
char wdh[];
{
    int  i, j, ln;
    char dum[8], commt[SentLen], cmt2[SentLen], dmy[15], *pt, *pt1;
 if(Dbg == 'Y') fprintf(dbg, "--- predit --- wdh = %s \n", wdh);
    if(*wdh == ' ') ptcut(wdh, 1);
    // em_bVň͂܂Ă镶ꍇ
    for(pt = wdh, i=0; pt != NULL; )
      if(pt = (char*)strstr(pt, "&#8212;")){ pt = pt+7; i++; }
 if(Dbg == 'Y') fprintf(dbg, "--- predit --- i = %d \n", i);
    if(i == 2){
      for(pt = wdh, j=0; pt != NULL; )
        if(pt = (char*)strstr(pt, "&#8212;")){
	  if(j==0){ ptreplace(pt, 7, "( "); pt = wdh; j++; }
	  else { ptreplace(pt, 7, ") "); pt = wdh; j++; }
        }
    }

    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&#8212;")){ ptreplace(pt, 7, ","); pt = wdh; }
    for(pt = wdh; pt != NULL; ) // utf em_bV
      if(pt = (char*)strstr(pt, "\201\\")){ ptreplace(pt, 2, ","); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "g")){ ptreplace(pt, 2, "\""); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "h")){ ptreplace(pt, 2, "\""); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "e")){ ptreplace(pt, 2, "\'"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "f")){ ptreplace(pt, 2, "\'"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "")){ ptreplace(pt, 2, "\\"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "Health, Labor and Welfare Ministry")){ ptreplace(pt, 34, "Mhlw"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "Why don't we")){ ptreplace(pt, 12, "Shall we"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "Costa Ricans")){ ptreplace(pt, 12, "Costa Rican"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "San Franciscans")){ ptreplace(pt, 15, "San Franciscan"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&Eacute;")){ ptreplace(pt, 8, "E"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&amp;")){ ptreplace(pt, 5, " & "); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&nbsp;")){ ptreplace(pt, 6, " "); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&rarr;")){ ptreplace(pt, 6, " "); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&quot;")){ ptreplace(pt, 6, "\""); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&lsquo;")){ ptreplace(pt, 7, "`"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&rsquo;")){ ptreplace(pt, 7, "\'"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&lsaquo;")){ ptreplace(pt, 8, " "); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "&rsaquo;")){ ptreplace(pt, 8, " "); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, "\226")){ ptreplace(pt, 2, " "); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, ",\"")){ ptreplace(pt, 2, " \" ,"); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, ".\"")){ ptreplace(pt, 2, " \" ."); pt = wdh; }
    for(pt = wdh; pt != NULL; )
      if(pt = (char*)strstr(pt, ".\'\"")){ ptreplace(pt, 3, " \' \" ."); pt = wdh; }

//      if(pt = (char*)strstr(pt, "&quot;")){
//        if(*(pt+6) != ' '){ ptreplace(pt, 6, "\" "); pt = wdh; }
//        if(*(pt-1) != ' ' && pt != wdh){ ptreplace(pt, 6, " \""); pt = wdh; }
//      }
    ln = strlen(wdh);
    j = ln;
    for(i = ln-1; i >= 0; i--){
      // @internet addressKp
      if(wdh[i] == '!' || wdh[i] == '?' || wdh[i] == '<'){
        if(wdh[i] == '!' && wdh[i-1] == '<') continue;
  	insertc(wdh, i+1, ' ', j++);
	insertc(wdh, i, ' ', j++);
      }
      if(wdh[i] == ';' && strncmp(wdh+i-5, "&nbsp;", 6)
                       && strncmp(wdh+i-3, "&lt;", 4)
                       && strncmp(wdh+i-3, "&gt;", 4)
                       && strncmp(wdh+i-4, "&amp;", 5)
                       && strncmp(wdh+i-4, "&deg;", 5)
                       && strncmp(wdh+i-5, "&quot;", 6)
                       && strncmp(wdh+i-5, "&bull;", 6)
                       && strncmp(wdh+i-6, "&raquo;", 7)
                       && strncmp(wdh+i-7, "&middot;", 8)
                       && strncmp(wdh+i-5, "&copy;", 6)){
	insertc(wdh,i+1,' ', j++);
	insertc(wdh,i,' ',j++);
      }
      if(wdh[i] == '('){
	insertc(wdh,i+1,' ',j++);
	insertc(wdh,i,' ',j++);
      }
      if((wdh[i] == ':' || wdh[i] == '/') && !strstr(wdh, "http")){
	insertc(wdh,i+1,' ',j++);
	insertc(wdh,i,' ',j++);
      }
      if(wdh[i] == '#'){
        if(wdh[i-1] != '&') ptreplace(wdh+i, 1, "");
      }
      if(wdh[i] == '%'){ ptreplace(wdh+i, 1, " percent");	j += 7; }
      if(wdh[i] == '$'){ ptreplace(wdh+i, 1, "dollar ");	j += 6; }
      if(wdh[i] == '\\'){ ptreplace(wdh+i, 1, "yen ");	j += 3; }
      if(wdh[i] == '-'){
        // P'stripped-down'VXet[Y邽ߎb菈
//        if(strncmp(wdh+i-2, "ed-", 3) == 0){
//          ptreplace(wdh+i, 1, " ");
//        }
      }
      if(wdh[i] == '&'){
        if(strncmp(wdh+i, "&nbsp;", 6) == 0){
          ptreplace(wdh+i, 6, " ");	j -= 5;
        }

        else if(strncmp(wdh+i, "&lt;", 4) == 0 || strncmp(wdh+i, "&gt;", 4) == 0){
        }
        else if(strncmp(wdh+i, "&amp;", 5) == 0 || strncmp(wdh+i, "&deg;", 5) == 0){
        }
        else if(strncmp(wdh+i, "&middot;", 8) == 0){
        }
        else if(strncmp(wdh+i, "&raquo;", 7) == 0){
        }
        else if(strncmp(wdh+i, "&copy;", 6) == 0 || strncmp(wdh+i, "&quot;", 6) == 0 || strncmp(wdh+i, "&bull;", 6) == 0){
          ptinsert(wdh+i+6, " "); j++;
        }
        else{ ptreplace(wdh+i, 1, "and");	j += 2; }
      }
    }

    // ','̏ꍇ
    for(pt = wdh; pt != NULL; )
      if((pt = (char*)strstr(pt, ", ")) && *(pt-1) != ' '){ ptinsert(pt, " "); pt=pt+2; }

  if(Dbg == 'Y') fprintf(dbg, "--- predit ---,--- wdh = %s \n", wdh);


  /*    ln = strlen(wdh);   j = ln;
    for(i = ln-2; i > 0; i--){
      if(wdh[i] == ',' && i >= ln-4){
	insertc(wdh, i+1, ' ', j++);
	insertc(wdh, i, ' ', j++);
      }
      if(wdh[i] == ',' && i < ln-4){
	if(isdigit(wdh[i+1])==0 ||isdigit(wdh[i+2])==0 ||isdigit(wdh[i+3])==0){
	  insertc(wdh, i+1, ' ', j++);
	  insertc(wdh, i, ' ', j++);
	}
      }
    }*/
    ln = strlen(wdh);
    for(i = ln-1; i > 0; i--)
      if(wdh[i] == ' ' && wdh[i+1] == ' ') cutoff(wdh, i, 1);
    ln = strlen(wdh)-1;
    if(wdh[ln] == ',' && ln > 0 && wdh[ln-1] != ' ') insertc(wdh, ln,' ',ln+1);

    ln = strlen(wdh);
    j = ln;
    for(i = ln-1; i > 0; i--){
      if(wdh[i] == '.' && !isupper(wdh[i-1])){
        // ---- at 6 p.m.  ̂悤ȏꍇ
        if(wdh[i-2] == '.' && isalpha(wdh[i-1])){ strcat(wdh, " .");  j += 2;   }
//        else if(wdh[i-1] != '.' && wdh[i-1] != ' ') insertc(wdh, i, ' ', j++);
        break;
      }
//      if((pt = (char*)strchr(wdh+i, ' ')) && (pt1 = (char*)strchr(wdh+i, '@')) && pt1 < pt){
//          break;        
//      }
      if(wdh[i] != ' ' && wdh[i] != '.') break;
      if(wdh[i] == ' '){ wdh[i] = '\0';	j--; }
    }
    ln = strlen(wdh);	j = ln;
    for(i = ln-1; i >= 0; i--){
      if(wdh[i] == '\"' || wdh[i] == ']'){
//	if(wdh[i-1] != ' ') insertc(wdh, i, ' ', j++);
//	break;
        if(wdh[i+1] != ' ') insertc(wdh, i+1, ' ', j++);
        if(wdh[i-1] != ' ' && i > 0) insertc(wdh, i, ' ', j++);
      }
//      if(wdh[i] != ' ' && wdh[i] != '\"') break;
//      if(wdh[i] == ' '){ wdh[i] = '\0';	j--; }
    }
    ln =strlen(wdh);	right(wdh, dum, 3);
    if(strcmp(dum,". \"") == 0) ptinsert(wdh+ln-3, " ");

    ln = strlen(wdh);
    j = ln;	ct = 0;
    for(i = ln-1; i > 0; i--){
      if(wdh[i] == '\'' && (wdh[i+1] == ' ' || wdh[i+1] == '\0') && (wdh[i-1] != 's' || strncmp(wdh+i-2, "ss", 2) == 0)){
	replaces(wdh,i,1," \' ");	j +=2;	ct = 1;
      }
      if(wdh[i] == '\'' && wdh[i-1] == ' ' && ct == 1){
	replaces(wdh,i,1," \' ");	j +=2;	ct = 0;
      }
    }
    if(wdh[0] == '\''){ replaces(wdh,0,1,"\' ");	j++; }

    // '('̏
    pt = wdh;
    while(index(pt, '(') != 0){
      if(pt = (char*)index(pt, '(')){
        if(pt == wdh) break;
        if(pt1 = (char*)index(pt+1, ')')){
	  ptcpy(commt, pt+1, pt1);	strcpy(cmt2, pt1+1);
	  while(*commt == ' ') ptcut(commt, 1);
	  sprintf(dmy, "%d", ++*no);	*pt = '\0';
	  strink(pt, "%",dmy, cmt2, " ", "*",dmy, " ", commt, (char*)0);
          if(*(pt-1) != ' ') ptinsert(pt, " ");
          pt = pt + 2;
        }
        else{
	  printf("closing ')' missing \n");
          *pt = '[';
          if(*(pt+1) != ' ') ptinsert(pt+1, " ");
  	  //exit(1);
        }
      }
    }
    pt = wdh;
    while(index(pt, '(') != 0){
      if(pt = (char*)index(pt, '(')){
        *pt = '[';
        if(*(pt+1) != ' ') ptinsert(pt+1, " ");
        if(*(pt+2) == '\0') *(pt+1) = '\0';
      }
    }
    pt = wdh;
    while(index(pt, ')') != 0){
      if(pt = (char*)index(pt, ')')){
        *pt = ']';
        if(pt > wdh && *(pt-1) != ' ') ptinsert(pt, " ");
      }
    }

    if(strstr(wdh, "-->")) return;
    if((pt = (char*)strstr(wdh, "--")) && strncmp(pt-2, "<!", 2)){
      if(pt1 = (char*)strstr(pt+3, "--")){
	ptcpy(commt, pt+2, pt1);	strcpy(cmt2, " ");	strcat(cmt2, pt1+2);
      }
      else if(pt1 = (char*)strstr(pt+3, " .")){
	ptcpy(commt, pt+2, pt1);	strcpy(cmt2, pt1);
      }
      else{
	strcpy(commt, pt+2);	strcpy(cmt2, " ");
      }
      while(*commt == ' ') ptcut(commt, 1);
      sprintf(dmy, "*%d", ++*no);
      *pt = '\0';
      strink(pt, dmy, cmt2, " ",dmy, " ", commt, (char*)0);
      *pt = '%';
      ptinsert(pt, " ");
    }
    // P-P̏ꍇA-spaceɕϊ
    for(pt = wdh; pt != 0; ){
      if((pt = (char*)strstr(wdh, "-")) && strncmp(pt, "--", 2))
        ptreplace(pt, 1, " ");
    }
/*    if(strlen(wdh)>= SentLen){
      printf("Too long wdh \n\n");
      printf("%s \n", wdh);	exit(1);
    }*/

    ln = strlen(wdh);
    if((pt = (char*)strstr(wdh, "vol."))){
      if(*(pt+4) != ' ') ptinsert(pt+4, " ");
      if(*(pt-1) != ' ') ptinsert(pt, " ");
    }
    if((pt = (char*)strstr(wdh, "No."))){
      if(*(pt+3) != ' ') ptinsert(pt+3, " ");
      if(*(pt-1) != ' ') ptinsert(pt, " ");
    }
    if((pt = (char*)strstr(wdh, ".."))){
      if(*pt != ' ') ptinsert(pt, " ");
    }
    if((pt = (char*)strstr(wdh, "OK."))){
      if(*pt != ' ') ptinsert(pt+2, " ");
    }
    if((pt = (char*)strstr(wdh, "s'")) && (pt1=(char*)strchr(wdh, '\'')) < pt){
      if(strncmp(pt1, "'ll", 3) && strncmp(pt1, "'not", 4) )
        if(*(pt+2) == ' ' || *(pt+2) == '\0' ) ptinsert(pt+1, " ");
    }
    while(*wdh == ' ') ptcut(wdh, 1);
}

predit2(wdh, no)
int  *no;
char wdh[];
{
}

/*------- posted ------------------------------------------*/

siage(jps)
char jps[];
{
    int  i;
    char c0;
    char *pt1, *pt2;
    c0 = cj[1][0];
    if(c0 == '0' || c0 == '?' || c0 == '!' || c0 == '\0') ct = 0;
    jps[0] = '\0';
    for(i = 0; i <= wnb; i++){
      if(Dbg == 'Y') fprintf(dbg, "--- siage --- i = %d %s \n", i, cj[i]);
      ptcut(cj[i], 1);
      while((pt1 = (char*)index(cj[i], '(')) && (pt2 = (char*)index(pt1+1, ')'))){
        ptptcut(pt1, pt2);
      }
      strcat(jps, cj[i]);
    }

}

resave(){
    FILE *fp, *fp1;
    char file0[50], file1[50], buf[280];
    int byt = 0;
/*    int  flg, i;*/
//    sprintf(file0, "%sOBJECT", dir);
//    sprintf(file1, "%s$$$", dir);
    strcpy(file0, "OBJECT");
    strcpy(file1, "$$$");
    fp = fopen(file0, "r");	fp1 = fopen(file1, "w");
    while((char) 1){
      if((char*)fgets(buf, 260, fp) == '\0') break;
      InsertLF(buf, 234);	InsertLF(buf, 156);
      InsertLF(buf, 78);
/*      if(strlen(buf) > 78+1){ flg = 0;
        for(i = 0; i < 6; i++){
	  if(iskanji(buf[70+2*i]) && (! iskanji2(buf[70+2*i]))) flg = 1;
	  if((! iskanji(buf[71+2*i])) && iskanji2(buf[71+2*i])) flg = 1;
        }
	if(flg == 1) ptinsert(buf+78, "\n");
        else ptinsert(buf+77, "\n");
      }*/
      fputs(buf, fp1);	byt += strlen(buf);
      fprintf(fp1, "\0");	/* Kv */
    }
    fclose(fp);		fprintf(fp1, "(%d)\n", byt);
    fclose(fp1);    unlink(file0);    rename(file1, file0);
}

InsertLF(char *buf, int n)
{
    int  flg, i;
    unsigned char c;
    if(strlen(buf) > n+1){ flg = 0;
      for(i = 0; i < 6; i++){
        c = buf[n-8+2*i];
        if(iskanji(c) && (! iskanji2(c))) flg = 1;
        c = buf[n-7+2*i];
        if((! iskanji(c)) && iskanji2(c)) flg = 1;
      }
      if(flg == 1) ptinsert(buf+n, "\n");
      else ptinsert(buf+n-1, "\n");
    }
}

// 񒆂̉p啶ɕϊ
char StrToLower(char *s)
{
  char *p;

  for(p = s; *p; p++)       // pʂłȂ
    *p = tolower(*p);
  return(*s);
}

char StrnToLower(char *s, int n)
{
  char *p;
  for(p = s; p < s+n; p++)
    *p = tolower(*p);
  return(*s);
}

// |󌋉ʂoȂƂł΂ׂ̈̃JE^

int ini_count(void){
  FILE *fp;
  int count;
  char buf[16];

  fp = fopen("COUNTER", "w");

  count = 0;
  fseek(fp, 0, SEEK_SET);
  fprintf(fp, "%d", count);
  fclose(fp);
  return count;
}

int get_count(void){
  FILE *fp;
  int count;
  char buf[16];

  fp = fopen("COUNTER", "r+");
  fgets(buf, 16, fp);
  count = atoi(buf) + 1;
  fseek(fp, 0, SEEK_SET);
  fprintf(fp, "%d", count);
  fclose(fp);
  return count;
}

int ini_debug(void){
  FILE *fp;

  fp = fopen("DEBUG", "w");

  fclose(fp);
  return;
}

int add_debug(char *str, int num){
  FILE *fp;

  fp = fopen("DEBUG", "a");

  fprintf(fp, "%s %d \n", str, num);
  fclose(fp);
  return;
}
